@@ -16,5 +16,8 @@ __all__ = [
 		"extras_require",
 		]
 
-__version__ = "0.0.12"
-extras_require = {"readme": ["readme-renderer[md]>=27.0"], "all": ["readme-renderer[md]>=27.0"]}
+__version__ = "0.0.13"
+extras_require = {
+		"readme": ["docutils==0.16", "pyproject-parser[readme]>=0.1.0"],
+		"all": ["docutils==0.16", "pyproject-parser[readme]>=0.1.0"]
+		}
