@@ -34,6 +34,7 @@ import posixpath
 import re
 import shutil
 import tarfile
+import warnings
 from abc import ABC, abstractmethod
 from email.headerregistry import Address
 from email.message import EmailMessage
@@ -216,7 +217,7 @@ class AbstractBuilder(ABC):
 		if self.verbose:
 			self._echo(f"Writing {written_file.relative_to(self.build_dir).as_posix()}")
 
-	def copy_additional_files(self) -> None:  # pylint: disable=useless-return
+	def copy_additional_files(self) -> None:
 		"""
 		Copy additional files to the build directory, as specified in the ``additional-files`` key.
 		"""
@@ -225,11 +226,12 @@ class AbstractBuilder(ABC):
 
 	def parse_additional_files(self, *entries: str) -> None:  # pylint: disable=useless-return
 		r"""
-		Copy additional files to the build directory,
-		by parsing `MANIFEST.in <https://packaging.python.org/guides/using-manifest-in/>`_-style entries.
+		Copy additional files to the build directory, by parsing `MANIFEST.in`_-style entries.
+
+		.. _MANIFEST.in: https://packaging.python.org/guides/using-manifest-in/
 
 		:param \*entries:
-		"""  # noqa: D400
+		"""
 
 		def copy_file(filename):
 			target = self.build_dir / filename.relative_to(self.project_dir)
@@ -264,6 +266,9 @@ class AbstractBuilder(ABC):
 						exclude_file.unlink()
 						self.report_removed(exclude_file)
 
+			else:  # pragma: no cover
+				warnings.warn(f"Unsupported command in 'additional-files': {entry}")
+
 		#
 		# elif parts[0] == "global-include":
 		# 	for include_pat in parts[1:]:
@@ -301,19 +306,20 @@ class AbstractBuilder(ABC):
 		:param dest_dir: The directory to write the files into.
 		"""
 
-		if "license" in self.config:
+		if self.config.get("license", None) is not None:
 			target = dest_dir / "LICENSE"
 			target.parent.maybe_make(parents=True)
-			target.write_clean(self.config["license"])
+			target.write_clean(self.config["license"].text)
 			self.report_written(target)
 
 	def write_metadata(self, metadata_file: PathPlus):
 		"""
-		Write `Core Metadata <https://packaging.python.org/specifications/core-metadata>`_
-		to the given file.
+		Write `Core Metadata`_ to the given file.
+
+		.. _Core Metadata: https://packaging.python.org/specifications/core-metadata
 
 		:param metadata_file:
-		"""  # noqa: D400
+		"""
 
 		metadata = EmailMessage()
 
@@ -404,8 +410,8 @@ class AbstractBuilder(ABC):
 		if self.config["readme"] is None:
 			description = ''
 		else:
-			metadata["Description-Content-Type"] = self.config["readme"]["content-type"]
-			description = self.config["readme"]["text"]
+			metadata["Description-Content-Type"] = self.config["readme"].content_type
+			description = self.config["readme"].text
 
 		metadata_file.write_lines([
 				# TODO: https://github.com/python/typeshed/issues/5094
@@ -552,15 +558,15 @@ class SDistBuilder(AbstractBuilder):
 		if self.config["readme"] is None:
 			return
 
-		if self.config["readme"]["content-type"] == "text/x-rst":
+		if self.config["readme"].content_type == "text/x-rst":
 			target = self.build_dir / "README.rst"
-		elif self.config["readme"]["content-type"] == "text/markdown":
+		elif self.config["readme"].content_type == "text/markdown":
 			target = self.build_dir / "README.md"
 		else:
 			target = self.build_dir / "README"
 
 		target.parent.maybe_make(parents=True)
-		target.write_clean(self.config["readme"]["text"])
+		target.write_clean(self.config["readme"].text)
 		self.report_written(target)
 
 	build = build_sdist
